@@ -1,3 +1,4 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,too-many-locals,unused-import
 """
 Main interface for sso-oidc service client
 
@@ -7,22 +8,19 @@ Usage::
     import boto3
     from mypy_boto3_sso_oidc import SSOOIDCClient
 
-    session = boto3.Session()
-
     client: SSOOIDCClient = boto3.client("sso-oidc")
-    session_client: SSOOIDCClient = session.client("sso-oidc")
     ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from typing import Any, Dict, List, TYPE_CHECKING, Type
+from typing import Any, Dict, List, Type
+
 from botocore.exceptions import ClientError as Boto3ClientError
+
 from mypy_boto3_sso_oidc.type_defs import (
     CreateTokenResponseTypeDef,
     RegisterClientResponseTypeDef,
     StartDeviceAuthorizationResponseTypeDef,
 )
 
-
 __all__ = ("SSOOIDCClient",)
 
 
